@@ -99,3 +99,41 @@ void exclude_clear() {
   excludes = NULL;
 }
 
+
+/* 
+ * Exclusion of directories that contain only cached information.
+ * See http://www.brynosaurus.com/cachedir/
+ */
+#define CACHEDIR_TAG_FILENAME "CACHEDIR.TAG"
+#define CACHEDIR_TAG_SIGNATURE "Signature: 8a477f597d28d172789f06886806bc55"
+
+int has_cachedir_tag(const char *name) {
+  static int path_l = 1024;
+  static char *path = NULL;
+  int l;
+  const size_t signature_l = sizeof CACHEDIR_TAG_SIGNATURE - 1;
+  char buf[signature_l];
+  FILE *f;
+  int match = 0;
+
+  /* Compute the required length for `path`. */
+  l = strlen(name) + sizeof CACHEDIR_TAG_FILENAME + 2;
+  if(l > path_l || path == NULL) {
+    path_l = path_l * 2;
+    if(path_l < l)
+      path_l = l;
+    /* We don't need to copy the content of `path`, so it's more efficient to
+     * use `free` + `malloc`. */
+    free(path);
+    path = malloc(path_l);
+  }
+  snprintf(path, path_l, "%s/%s", name, CACHEDIR_TAG_FILENAME);
+  f = fopen(path, "rb");
+
+  if(f != NULL) {
+    match = ((fread(buf, 1, signature_l, f) == signature_l) &&
+                !memcmp(buf, CACHEDIR_TAG_SIGNATURE, signature_l));
+    fclose(f);
+  }
+  return match;
+}
