@@ -29,6 +29,7 @@
 #include "config.h"
 #include <stdio.h>
 #include <stddef.h>
+#include <limits.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 
@@ -85,6 +86,8 @@ extern int pstate;
 extern int read_only;
 /* minimum screen update interval when calculating, in ms */
 extern long update_delay;
+/* filter directories with CACHEDIR.TAG */
+extern int cachedir_tags;
 
 /* handle input from keyboard and update display */
 int input_handle(int);
