@@ -32,7 +32,7 @@
 int page, start;
 
 
-#define KEYS 14
+#define KEYS 16
 char *keys[KEYS*2] = {
 /*|----key----|  |----------------description----------------|*/
         "up, k", "Move cursor up",
@@ -41,10 +41,12 @@ char *keys[KEYS*2] = {
    "left, <, h", "Open parent directory",
             "n", "Sort by name (ascending/descending)",
             "s", "Sort by size (ascending/descending)",
+            "C", "Sort by items (ascending/descending)",
             "d", "Delete selected file or directory",
             "t", "Toggle dirs before files when sorting",
             "g", "Show percentage and/or graph",
             "a", "Toggle between apparent size and disk usage",
+            "c", "Toggle display of child item counts",
             "e", "Show/hide hidden or excluded files",
             "i", "Show information about selected item",
             "r", "Recalculate the current directory",
