@@ -28,9 +28,11 @@
 #include <string.h>
 #include <stdlib.h>
 #include <ncurses.h>
+#include <locale.h>
 
 int winrows, wincols;
 int subwinr, subwinc;
+char thou_sep;
 
 
 char *cropstr(const char *from, int s) {
@@ -62,15 +64,17 @@ char *formatsize(int64_t from) {
   else if(r < 1023e3f) { c = 'K'; r/=1024.0f; }
   else if(r < 1023e6f) { c = 'M'; r/=1048576.0f; }
   else if(r < 1023e9f) { c = 'G'; r/=1073741824.0f; }
-  else                 { c = 'T'; r/=1099511627776.0f; }
+  else if(r < 1023e12f){ c = 'T'; r/=1099511627776.0f; }
+  else if(r < 1023e15f){ c = 'P'; r/=1125899906842624.0f; }
+  else                 { c = 'E'; r/=1152921504606846976.0f; }
   sprintf(dat, "%5.1f%c%cB", r, c, c == ' ' ? ' ' : 'i');
   return dat;
 }
 
 
 char *fullsize(int64_t from) {
-  static char dat[20]; /* max: 999.999.999.999.999 */
-  char tmp[20];
+  static char dat[26]; /* max: 9.223.372.036.854.775.807  (= 2^63-1) */
+  char tmp[26];
   int64_t n = from;
   int i, j;
 
@@ -86,7 +90,7 @@ char *fullsize(int64_t from) {
   while(i--) {
     dat[j++] = tmp[i];
     if(i != 0 && i%3 == 0)
-      dat[j++] = '.';
+      dat[j++] = thou_sep;
   }
   dat[j] = '\0';
 
@@ -94,6 +98,16 @@ char *fullsize(int64_t from) {
 }
 
 
+void read_locale() {
+  char *locale_thou_sep = localeconv()->thousands_sep;
+  if (locale_thou_sep && 1 == strlen(locale_thou_sep)) {
+    thou_sep = locale_thou_sep[0];
+  } else {
+    thou_sep = '.';
+  }
+}
+
+
 int ncresize(int minrows, int mincols) {
   int ch;
 
@@ -184,8 +198,8 @@ static void freedir_hlnk(struct dir *d) {
           if(pt==par)
             i=0;
     if(i) {
-      par->size -= d->size;
-      par->asize -= d->asize;
+      par->size = adds64(par->size, -d->size);
+      par->asize = adds64(par->size, -d->asize);
     }
   }
 
@@ -285,8 +299,8 @@ struct dir *getroot(struct dir *d) {
 
 void addparentstats(struct dir *d, int64_t size, int64_t asize, int items) {
   while(d) {
-    d->size += size;
-    d->asize += asize;
+    d->size = adds64(d->size, size);
+    d->asize = adds64(d->asize, asize);
     d->items += items;
     d = d->parent;
   }
