@@ -71,6 +71,9 @@ char *formatsize(int64_t );
 /* int2string with thousand separators */
 char *fullsize(int64_t);
 
+/* read locale information from the environment */
+void read_locale();
+
 /* recursively free()s a directory tree */
 void freedir(struct dir *);
 
@@ -81,6 +84,15 @@ char *getpath(struct dir *);
 /* returns the root element of the given dir struct */
 struct dir *getroot(struct dir *);
 
+/* Add two signed 64-bit integers. Returns INT64_MAX if the result would
+ * overflow, or 0 if it would be negative. At least one of the integers must be
+ * positive.
+ * I use uint64_t's to detect the overflow, as (a + b < 0) relies on undefined
+ * behaviour, and (INT64_MAX - b >= a) didn't work for some reason. */
+#define adds64(a, b) ((a) > 0 && (b) > 0\
+    ? ((uint64_t)(a) + (uint64_t)(b) > (uint64_t)INT64_MAX ? INT64_MAX : (a)+(b))\
+    : (a)+(b) < 0 ? 0 : (a)+(b))
+
 /* Adds a value to the size, asize and items fields of *d and its parents */
 void addparentstats(struct dir *, int64_t, int64_t, int);
 
